Changelog
=========


1.0a4 (2024-03-07)
------------------

- WEB-4089 : Add recaptcha to contact-info form
  [boulch]


1.0a3 (2020-02-11)
------------------

- Override listing_summary.pt to get french translation on mosaic.
  [bsuttor]


1.0a2 (2020-01-29)
------------------

- Move Login link from User actions to Site actions
  [laulaz]


1.0a1 (2020-01-29)
------------------

- Initial release.
  [bsuttor]
